import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.NavigationBar
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.navigation.NavType
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import androidx.navigation.navArgument
import com.example.myapplication.R
import com.example.myapplication.navigation.NavItem
import com.example.myapplication.ui.theme.MyApplicationTheme

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun Navbar() {
    val navController = rememberNavController()
    val items = listOf(
        NavItem("main", "Главная", R.drawable.home),
        NavItem("category", "Каталог", R.drawable.search),
        NavItem("cart", "Корзина", R.drawable.cart),
    )
    val videocars = listOf(
        Product(3, "MSI GeForce RTX 4090 VENTUS 3X OC", "Info", 210999, R.drawable.product1),
        Product(4, "Palit GeForce GTX 1660 SUPER", "Info", 25999, R.drawable.product2),
    )
    val processors = listOf(
        Product(1,"Intel Celeron G5905 OEM","Info",4099, R.drawable.product3),
        Product(2,"AMD Ryzen 5 4500 BOX","Info",9799, R.drawable.product4),
    )

    Scaffold(
        bottomBar = {
            NavigationBar {
                items.forEach{item ->
                    NavigationBarItem(
                        icon = {
                            Image(
                                painter = painterResource(item.icon),
                                contentDescription = null,
                                modifier = Modifier.size(35.dp)
                            )
                        },
                        label={ Text(item.label) },
                        onClick = {
                            navController.navigate(item.route)
                        },
                        selected = false,
                        modifier = Modifier.fillMaxSize()
                    )
                }
            }
        }
    )
    { innerPaddings ->
        NavHost(
            navController = navController,
            startDestination = "authorization",
            modifier = Modifier.padding(innerPaddings)
        ) {
            composable("authorization") { Authorization(navController) }
            composable("registration") { Registration(navController) }

            composable("main") { Main(navController) }
            composable("category") { Сategory(navController) }
            composable("cart") { Cart(navController)}

            composable("processors") {  CatalogItems(navController,"Процессоры", processors)}
            composable("videocards") { CatalogItems(navController,"Видеокарты", videocars)}
        }
    }
}

@Preview(name="Navbar")
@Composable
fun PreviewNavbar() {
    MyApplicationTheme {
        // A surface container using the 'background' color from the theme
        Surface(modifier = Modifier.fillMaxSize(), color = MaterialTheme.colorScheme.background) {
            Navbar()
        }
    }
}
